@@ -699,7 +699,7 @@ CREATE TABLE IF NOT EXISTS wp_site_plugins (
 CREATE TABLE IF NOT EXISTS wp_update_history (
     id INT PRIMARY KEY AUTO_INCREMENT,
     site_id INT NOT NULL,
-    update_type ENUM('core', 'plugin', 'theme') NOT NULL,
+    update_type ENUM('core', 'plugin', 'theme', 'all') NOT NULL,
     item_name VARCHAR(255),
     old_version VARCHAR(20),
     new_version VARCHAR(20),
