@@ -593,5 +593,120 @@ class haproxy_manager {
             ];
         }
     }
+    
+    /**
+     * Block an IP address in HAProxy
+     * 
+     * @param string $ip_address IP address to block
+     * @param string $reason Reason for blocking
+     * @param string $blocked_by Who initiated the block
+     * @return bool True on success, false on failure
+     */
+    public function block_ip($ip_address, $reason = 'Manual block', $blocked_by = 'WHP System') {
+        if (!filter_var($ip_address, FILTER_VALIDATE_IP)) {
+            error_log("HAProxy Manager: Invalid IP address provided for blocking: $ip_address");
+            return false;
+        }
+        
+        $data = [
+            'ip_address' => $ip_address,
+            'reason' => $reason,
+            'blocked_by' => $blocked_by
+        ];
+        
+        $result = $this->makeApiRequest('POST', '/api/blocked-ips', $data);
+        
+        if ($result['success']) {
+            error_log("HAProxy Manager: Successfully blocked IP $ip_address");
+            return true;
+        } elseif (isset($result['data']['status']) && $result['data']['status'] === 'error' && 
+                  strpos($result['data']['message'], 'already blocked') !== false) {
+            // IP is already blocked, consider this a success
+            error_log("HAProxy Manager: IP $ip_address is already blocked");
+            return true;
+        }
+        
+        error_log("HAProxy Manager: Failed to block IP $ip_address - " . ($result['error'] ?? 'Unknown error'));
+        return false;
+    }
+    
+    /**
+     * Unblock an IP address in HAProxy
+     * 
+     * @param string $ip_address IP address to unblock
+     * @return bool True on success, false on failure
+     */
+    public function unblock_ip($ip_address) {
+        if (!filter_var($ip_address, FILTER_VALIDATE_IP)) {
+            error_log("HAProxy Manager: Invalid IP address provided for unblocking: $ip_address");
+            return false;
+        }
+        
+        $data = [
+            'ip_address' => $ip_address
+        ];
+        
+        $result = $this->makeApiRequest('DELETE', '/api/blocked-ips', $data);
+        
+        if ($result['success']) {
+            error_log("HAProxy Manager: Successfully unblocked IP $ip_address");
+            return true;
+        }
+        
+        error_log("HAProxy Manager: Failed to unblock IP $ip_address - " . ($result['error'] ?? 'Unknown error'));
+        return false;
+    }
+    
+    /**
+     * Get list of blocked IPs from HAProxy
+     * 
+     * @return array Array of blocked IP information or empty array on failure
+     */
+    public function get_blocked_ips() {
+        $result = $this->makeApiRequest('GET', '/api/blocked-ips');
+        
+        if ($result['success']) {
+            return $result['data'] ?: [];
+        }
+        
+        error_log("HAProxy Manager: Failed to get blocked IPs list - " . ($result['error'] ?? 'Unknown error'));
+        return [];
+    }
+    
+    /**
+     * Check if an IP is blocked in HAProxy
+     * 
+     * @param string $ip_address IP address to check
+     * @return bool True if blocked, false otherwise
+     */
+    public function is_ip_blocked($ip_address) {
+        if (!filter_var($ip_address, FILTER_VALIDATE_IP)) {
+            return false;
+        }
+        
+        $blocked_ips = $this->get_blocked_ips();
+        foreach ($blocked_ips as $blocked) {
+            if (isset($blocked['ip_address']) && $blocked['ip_address'] === $ip_address) {
+                return true;
+            }
+        }
+        
+        return false;
+    }
+    
+    /**
+     * Check HAProxy service health
+     * 
+     * @return array Health status information or false on failure
+     */
+    public function check_health() {
+        $result = $this->makeApiRequest('GET', '/health');
+        
+        if ($result['success']) {
+            return $result['data'];
+        }
+        
+        return false;
+    }
 }
 ?> 
\ No newline at end of file
