@@ -672,8 +672,8 @@ class log_monitor_manager {
         
         // Also block in HAProxy for full service-wide blocking
         try {
-            require_once('/docker/whp/web/libs/haproxy_api_manager.php');
-            $haproxy = new haproxy_api_manager();
+            require_once('/docker/whp/web/libs/haproxy_manager.php');
+            $haproxy = new haproxy_manager();
             $haproxy->block_ip($ip, "$service: $reason", 'WHP Log Monitor');
         } catch (Exception $e) {
             error_log("Failed to block IP in HAProxy from log monitor: " . $e->getMessage());
