@@ -153,17 +153,18 @@ class security_manager {
         }
     }
     
-    public function block_ip($ip_address, $reason = 'Manual block', $failed_attempts = 0) {
+    public function block_ip($ip_address, $reason = 'Manual block', $failed_attempts = 0, $indefinite = false) {
         // Don't block whitelisted IPs
         if ($this->is_ip_whitelisted($ip_address)) {
             return false;
         }
         
         // Store in local database
+        $unblock_time = $indefinite ? 0 : (time() + $this->block_duration); // 0 means indefinite/manual unblock only
         $stmt = $this->db->prepare('INSERT OR REPLACE INTO blocked_ips (ip_address, block_time, unblock_time, reason, failed_attempts, manual_block) VALUES (:ip, :block_time, :unblock_time, :reason, :attempts, :manual)');
         $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
         $stmt->bindValue(':block_time', time(), SQLITE3_INTEGER);
-        $stmt->bindValue(':unblock_time', time() + $this->block_duration, SQLITE3_INTEGER);
+        $stmt->bindValue(':unblock_time', $unblock_time, SQLITE3_INTEGER);
         $stmt->bindValue(':reason', $reason, SQLITE3_TEXT);
         $stmt->bindValue(':attempts', $failed_attempts, SQLITE3_INTEGER);
         $stmt->bindValue(':manual', ($reason === 'Manual block') ? 1 : 0, SQLITE3_INTEGER);
@@ -171,8 +172,8 @@ class security_manager {
         
         // Also block in HAProxy for full service-wide blocking
         try {
-            require_once('/docker/whp/web/libs/haproxy_api_manager.php');
-            $haproxy = new haproxy_api_manager();
+            require_once('/docker/whp/web/libs/haproxy_manager.php');
+            $haproxy = new haproxy_manager();
             $haproxy->block_ip($ip_address, $reason, 'WHP Security Manager');
         } catch (Exception $e) {
             error_log("Failed to block IP in HAProxy: " . $e->getMessage());
@@ -207,8 +208,8 @@ class security_manager {
         
         // Also unblock from HAProxy
         try {
-            require_once('/docker/whp/web/libs/haproxy_api_manager.php');
-            $haproxy = new haproxy_api_manager();
+            require_once('/docker/whp/web/libs/haproxy_manager.php');
+            $haproxy = new haproxy_manager();
             $haproxy->unblock_ip($ip_address);
         } catch (Exception $e) {
             error_log("Failed to unblock IP from HAProxy: " . $e->getMessage());
@@ -237,15 +238,15 @@ class security_manager {
         }
         
         // Check if IP is blocked
-        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE ip_address = :ip AND unblock_time > :time');
+        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE ip_address = :ip AND (unblock_time > :time OR unblock_time = 0)');
         $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
         $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
         $row = $result->fetchArray(SQLITE3_ASSOC);
         
         if ($row) {
-            // Auto-unblock if time has expired
-            if ($row['unblock_time'] <= time()) {
+            // Auto-unblock if time has expired (but not for indefinite blocks with unblock_time = 0)
+            if ($row['unblock_time'] > 0 && $row['unblock_time'] <= time()) {
                 $this->unblock_ip($ip_address);
                 return false;
             }
