@@ -35,9 +35,11 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
             case 'block_ip':
                 if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
                     $reason = !empty($_POST['reason']) ? substr(trim($_POST['reason']), 0, 255) : 'Manual block';
-                    $result = $SecManager->block_ip($_POST['ip_address'], $reason);
+                    $indefinite = isset($_POST['indefinite']) && $_POST['indefinite'] == '1';
+                    $result = $SecManager->block_ip($_POST['ip_address'], $reason, 0, $indefinite);
                     if ($result) {
-                        $message = 'IP address blocked successfully: ' . htmlspecialchars($_POST['ip_address']);
+                        $block_type = $indefinite ? 'indefinitely' : 'temporarily';
+                        $message = 'IP address blocked ' . $block_type . ': ' . htmlspecialchars($_POST['ip_address']);
                         $message_type = 'success';
                     } else {
                         $message = 'Error blocking IP address (may be exempted)';
@@ -474,77 +476,66 @@ $access_stats = $PermManager->get_system_access_stats(30);
                         <label for="block_reason" class="form-label">Reason (optional)</label>
                         <input type="text" class="form-control" id="block_reason" name="reason" placeholder="Manual block">
                     </div>
+                    <div class="mb-3">
+                        <div class="form-check">
+                            <input class="form-check-input" type="checkbox" id="indefinite_block" name="indefinite" value="1">
+                            <label class="form-check-label" for="indefinite_block">
+                                Block indefinitely
+                            </label>
+                        </div>
+                    </div>
                     <button type="submit" class="btn btn-danger">Block IP</button>
                 </form>
             </div>
         </div>
     </div>
-    <!-- Add to Exemption List Panel -->
-    <div class="col-md-8">
+    <!-- Unblock IP Panel -->
+    <div class="col-md-4">
         <div class="card h-100">
             <div class="card-header">
-                <h5 class="card-title mb-0">Add to Exemption List</h5>
+                <h5 class="card-title mb-0">Unblock IP Address</h5>
+            </div>
+            <div class="card-body">
+                <form method="POST" action="">
+                    <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
+                    <input type="hidden" name="action" value="unblock_ip">
+                    <div class="mb-3">
+                        <label for="unblock_ip" class="form-label">IP Address</label>
+                        <input type="text" class="form-control" id="unblock_ip" name="ip_address" placeholder="192.168.1.100" required>
+                    </div>
+                    <button type="submit" class="btn btn-warning">Unblock IP</button>
+                </form>
+            </div>
+        </div>
+    </div>
+    <!-- Add Exemption Panel -->
+    <div class="col-md-4">
+        <div class="card h-100">
+            <div class="card-header">
+                <h5 class="card-title mb-0">Add Exemption</h5>
             </div>
             <div class="card-body">
                 <form method="POST" action="">
                     <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                     <input type="hidden" name="action" value="add_exemption">
-                    <div class="row">
-                        <div class="col-md-6">
-                            <div class="mb-3">
-                                <label for="exemption_ip" class="form-label">IP Address</label>
-                                <input type="text" class="form-control" id="exemption_ip" name="ip_address" placeholder="192.168.1.100" required>
-                            </div>
-                        </div>
-                        <div class="col-md-6">
-                            <div class="mb-3">
-                                <label for="exemption_description" class="form-label">Description (optional)</label>
-                                <input type="text" class="form-control" id="exemption_description" name="description" placeholder="Office, Home, etc.">
-                            </div>
-                        </div>
+                    <div class="mb-3">
+                        <label for="exemption_ip" class="form-label">IP Address</label>
+                        <input type="text" class="form-control" id="exemption_ip" name="ip_address" placeholder="192.168.1.100" required>
                     </div>
-                    <button type="submit" class="btn btn-success">Add to Exemption List</button>
+                    <div class="mb-3">
+                        <label for="exemption_description" class="form-label">Description (optional)</label>
+                        <input type="text" class="form-control" id="exemption_description" name="description" placeholder="Office, Home, etc.">
+                    </div>
+                    <button type="submit" class="btn btn-success">Add Exemption</button>
                 </form>
             </div>
         </div>
     </div>
 </div>
-<div class="row g-4">
-    <!-- Blocked IPs Table -->
-    <div class="col-md-6">
-        <div class="card h-100">
-            <div class="card-header">
-                <h5 class="card-title mb-0">Blocked IPs</h5>
-            </div>
-            <div class="card-body">
-                <div class="table-responsive">
-                    <table class="table table-striped table-hover">
-                        <thead class="table-dark">
-                            <tr><th>IP Address</th><th width="120">Action</th></tr>
-                        </thead>
-                        <tbody>
-                            <?php foreach ($blocked_ips as $ip_data): ?>
-                            <tr>
-                                <td><?php echo htmlspecialchars($ip_data['ip_address']); ?></td>
-                                <td>
-                                    <form method="POST" action="" style="display:inline;">
-                                        <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
-                                        <input type="hidden" name="action" value="unblock_ip">
-                                        <input type="hidden" name="ip_address" value="<?php echo htmlspecialchars($ip_data['ip_address']); ?>">
-                                        <button type="submit" class="btn btn-warning btn-sm">Unblock</button>
-                                    </form>
-                                </td>
-                            </tr>
-                            <?php endforeach; ?>
-                        </tbody>
-                    </table>
-                </div>
-            </div>
-        </div>
-    </div>
-    <!-- Exemption List Table -->
-    <div class="col-md-6">
-        <div class="card h-100">
+<!-- Exemption List Table -->
+<div class="row g-4 mb-5">
+    <div class="col-md-12">
+        <div class="card">
             <div class="card-header">
                 <h5 class="card-title mb-0">Exempt IPs</h5>
             </div>
@@ -555,6 +546,11 @@ $access_stats = $PermManager->get_system_access_stats(30);
                             <tr><th>IP Address</th><th>Description</th><th width="120">Action</th></tr>
                         </thead>
                         <tbody>
+                            <?php if (empty($exemption_ips)): ?>
+                            <tr>
+                                <td colspan="3" class="text-center text-muted">No exempt IPs configured</td>
+                            </tr>
+                            <?php else: ?>
                             <?php foreach ($exemption_ips as $ip): ?>
                             <tr>
                                 <td><?php echo htmlspecialchars($ip['ip_address']); ?></td>
@@ -569,6 +565,7 @@ $access_stats = $PermManager->get_system_access_stats(30);
                                 </td>
                             </tr>
                             <?php endforeach; ?>
+                            <?php endif; ?>
                         </tbody>
                     </table>
                 </div>
@@ -579,11 +576,16 @@ $access_stats = $PermManager->get_system_access_stats(30);
 
 <!-- Service Blocked IPs -->
 <?php 
-// Pagination setup
-$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
+// Pagination setup  
+$page = isset($_GET['p']) ? max(1, intval($_GET['p'])) : 1;
 $search = isset($_GET['search']) ? trim($_GET['search']) : '';
 $per_page = 25;
 
+// Sort IPs by IP address first
+usort($service_blocked_ips, function($a, $b) {
+    return strcmp($a['ip_address'], $b['ip_address']);
+});
+
 // Filter IPs based on search
 $filtered_ips = $service_blocked_ips;
 if (!empty($search)) {
@@ -606,12 +608,12 @@ if (!empty($service_blocked_ips)): ?>
         <div class="card">
             <div class="card-header d-flex justify-content-between align-items-center">
                 <h5 class="card-title mb-0">Blocked IPs</h5>
-                <form method="GET" action="" class="d-flex">
+                <form method="GET" action="?page=security-management" class="d-flex">
                     <input type="text" class="form-control form-control-sm me-2" name="search" 
                            placeholder="Search IP..." value="<?php echo htmlspecialchars($search); ?>" style="width: 200px;">
                     <button type="submit" class="btn btn-sm btn-primary">Search</button>
                     <?php if (!empty($search)): ?>
-                    <a href="?" class="btn btn-sm btn-secondary ms-2">Clear</a>
+                    <a href="?page=security-management" class="btn btn-sm btn-secondary ms-2">Clear</a>
                     <?php endif; ?>
                 </form>
             </div>
@@ -639,7 +641,31 @@ if (!empty($service_blocked_ips)): ?>
                             <?php else: ?>
                             <?php foreach ($current_page_ips as $blocked): ?>
                             <tr>
-                                <td><span class="badge bg-<?php echo $blocked['service_type'] == 'ssh' ? 'primary' : 'info'; ?>"><?php echo strtoupper($blocked['service_type']); ?></span></td>
+                                <td>
+                                    <?php 
+                                    $service_type = $blocked['service_type'];
+                                    $reason = $blocked['reason'] ?? '';
+                                    
+                                    // Determine the actual block source
+                                    if (stripos($reason, 'manual') !== false) {
+                                        $badge_class = 'warning';
+                                        $service_display = 'MANUAL';
+                                    } elseif (stripos($reason, 'whp') !== false) {
+                                        $badge_class = 'success';
+                                        $service_display = 'WHP';
+                                    } elseif ($service_type == 'ssh') {
+                                        $badge_class = 'primary';
+                                        $service_display = 'SSH';
+                                    } elseif ($service_type == 'ftp') {
+                                        $badge_class = 'info';
+                                        $service_display = 'FTP';
+                                    } else {
+                                        $badge_class = 'secondary';
+                                        $service_display = strtoupper($service_type);
+                                    }
+                                    ?>
+                                    <span class="badge bg-<?php echo $badge_class; ?>"><?php echo $service_display; ?></span>
+                                </td>
                                 <td><code><?php echo htmlspecialchars($blocked['ip_address']); ?></code></td>
                                 <td>
                                     <small title="<?php echo date('Y-m-d H:i:s', $blocked['block_time']); ?>">
@@ -699,7 +725,7 @@ if (!empty($service_blocked_ips)): ?>
                     <ul class="pagination justify-content-center mb-0">
                         <?php if ($page > 1): ?>
                         <li class="page-item">
-                            <a class="page-link" href="?page=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>">Previous</a>
+                            <a class="page-link" href="?page=security-management&p=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>">Previous</a>
                         </li>
                         <?php endif; ?>
                         
@@ -709,7 +735,7 @@ if (!empty($service_blocked_ips)): ?>
                         
                         if ($start_page > 1): ?>
                         <li class="page-item">
-                            <a class="page-link" href="?page=1&search=<?php echo urlencode($search); ?>">1</a>
+                            <a class="page-link" href="?page=security-management&p=1&search=<?php echo urlencode($search); ?>">1</a>
                         </li>
                         <?php if ($start_page > 2): ?>
                         <li class="page-item disabled"><span class="page-link">...</span></li>
@@ -718,7 +744,7 @@ if (!empty($service_blocked_ips)): ?>
                         
                         <?php for ($i = $start_page; $i <= $end_page; $i++): ?>
                         <li class="page-item <?php echo $i == $page ? 'active' : ''; ?>">
-                            <a class="page-link" href="?page=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>"><?php echo $i; ?></a>
+                            <a class="page-link" href="?page=security-management&p=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>"><?php echo $i; ?></a>
                         </li>
                         <?php endfor; ?>
                         
@@ -727,13 +753,13 @@ if (!empty($service_blocked_ips)): ?>
                         <li class="page-item disabled"><span class="page-link">...</span></li>
                         <?php endif; ?>
                         <li class="page-item">
-                            <a class="page-link" href="?page=<?php echo $total_pages; ?>&search=<?php echo urlencode($search); ?>"><?php echo $total_pages; ?></a>
+                            <a class="page-link" href="?page=security-management&p=<?php echo $total_pages; ?>&search=<?php echo urlencode($search); ?>"><?php echo $total_pages; ?></a>
                         </li>
                         <?php endif; ?>
                         
                         <?php if ($page < $total_pages): ?>
                         <li class="page-item">
-                            <a class="page-link" href="?page=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>">Next</a>
+                            <a class="page-link" href="?page=security-management&p=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>">Next</a>
                         </li>
                         <?php endif; ?>
                     </ul>
